# A local_scan() function to chain together multiple local_scan()s.
#
# This is dead easy because elspy uses Python exceptions to indicate
# message rejection.  You just call a series of existing local_scan()
# functions; if any one of them rejects the message, it raises
# RejectMessage (or TempRejectMessage) and the chain is broken.  If you
# get to the last local_scan() in the chain and fall off the end, then
# all of the local_scan()s have accepted the message, so the chain
# accepts it.  Finally, if one of the local_scan() functions raises
# AcceptMessage, the chain is broken and the message is immediately
# accepted.

__revision__ = "$Id: chain.py,v 1.3 2002/10/21 22:22:37 gward Exp $"


# These are the modules supplying us with local_scan() functions.
from elspy import execontent_simple, spamassassin

# Other stuff we need here.
from elspy import AcceptMessage


# This is just to demonstrate the AcceptMessage exception --
# automatically accept all message for the postmaster of this site,
# regardless of what other local_scan() functions in the same chain
# might think of them.  I'm not sure if this is a good idea, but you can
# do it at your site if you want.
LOCAL_DOMAINS = ("example.com", "example.net", "example.ca")

def local_scan_postmaster (info, headers, fd):
    pm_addrs = ["postmaster@%s" % domain for domain in LOCAL_DOMAINS]
    for recip in info.recipients_list:
        if recip in pm_addrs:
            raise AcceptMessage


def local_scan (info, headers, fd):
    # Here's the chain -- we just call each existing local_scan()
    # in turn until one of them raises AcceptMessage, RejectMessage,
    # or TempRejectMessage.
    local_scan_postmaster(info, headers, fd)
    execontent_simple.local_scan(info, headers, fd)
    spamassassin.local_scan(info, headers, fd)
