"""elspy -- the Python library.  This package provides various functions
and classes useful for writing the Exim local_scan() function in Python.
It also provides several sample local_scan() implementations, which you
can invoke from your local exim_local_scan.py module.
"""

# Copyright (c) 2002 Gregory P. Ward.  All rights reserved.
# See README.txt for licensing information.
#
# The elspy home page is at http://elspy.sourceforge.net/ .

__revision__ = "$Id: __init__.py,v 1.15 2002/10/22 22:55:30 gward Exp $"

__version__ = "0.1.1"

import sys
from traceback import format_exception

# Some of the useful stuff lives in the _elspy pseudo-module,
# which is created by the code that's linked into Exim.  (Ie.
# don't go looking for _elspy.so in your Python library -- it
# doesn't exist!)
try:
    import _elspy
except ImportError:
    # Define fake versions of everything _elspy exports, so we can
    # "import elspy" in a Python interpreter that's not embedded in
    # Exim.  Handy for testing elspy code, or using it in other
    # contexts, or testing your local_scan().

    # Suppress setting excepthook below.
    _embedded = 0

    LOCAL_SCAN_ACCEPT = 0
    LOCAL_SCAN_REJECT = 1
    LOCAL_SCAN_TEMPREJECT = 2

    LOG_MAIN = 1
    LOG_REJECT = 16

    def expand_string (s):
        # Hmmm, could open a pipe to exim -be ...
        raise NotImplementedError

    def header_add (s):
        print "elspy: header_add(%r)" % s

    def log_write (selector, text):
        which = {LOG_MAIN: "main", LOG_REJECT: "reject"}[selector]
        print "LOG (%s): %s" % (which, text)
else:
    _embedded = 1
    from _elspy import \
         expand_string, log_write, header_add, \
         LOCAL_SCAN_ACCEPT, LOCAL_SCAN_TEMPREJECT, LOCAL_SCAN_REJECT, \
         LOG_MAIN, LOG_REJECT

# This is the _local_scan() that is usually called from the C
# local_scan() linked into Exim.
def _local_scan (info, headers, fd):
    from exim_local_scan import local_scan
    try:
        val = local_scan(EximInfo(info), HeaderList(headers), fd)
    except MessageDisposition, val:
        return (val.disposition, val.text)

    # Fell through to the end of local_scan() -- accept the message.
    return LOCAL_SCAN_ACCEPT, val


if _embedded:                           # embedded in Exim?
    def excepthook (exctype, value, traceback):
        lines = format_exception(exctype, value, traceback)
        text = ("".join(lines))[:-1]
        text = text.replace("%", "%%")
        log_write(LOG_MAIN, text)

    sys.excepthook = excepthook

# Other useful stuff lives in util.py -- import it from there
# so local_scan() authors don't have to know about
# the internal structure of this package.
from elspy.util import \
     MessageDisposition, AcceptMessage, RejectMessage, TempRejectMessage, \
     log_error, log_warning, get_fdpos, set_fdpos, \
     HeaderList, EximInfo
